QueryError<T> class

The state of the query when an error is thrown.

Inheritance

Constructors

QueryError({required DateTime timeCreated, T? data, required StackTrace stackTrace, required dynamic error})
The state of the query when an error is thrown.
const

Properties

data → T?
The data stored in the query;
final
error → dynamic
Current error for the query.
final
hashCode int
The hash code for this object.
no setteroverride
isError bool
True if the query has errored.
no setterinherited
isInitial bool
True if the query is in the initial state.
no setterinherited
isLoading bool
True if the query is currently fetching data.
no setterinherited
isSuccess bool
True if the query has successfully fetched data.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace
The stack trace of the error.
final
timeCreated DateTime
Timestamp of the query.
finalinherited

Methods

copyWithData(T data, [DateTime? timeCreated]) QueryStatus<T>
Copy the current state with new data
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override