StoredQuery class

The data stored in the database

Constructors

StoredQuery({required String key, required Object? data, required DateTime createdAt, Duration? storageDuration})
The data stored in the database

Properties

createdAt DateTime
The query expiry
final
data Object?
The query data
final
expiry DateTime?
The query expiry time.
final
hashCode int
The hash code for this object.
no setteroverride
isExpired bool
Whether the query is expired.
no setter
isNotExpired bool
Whether the query is not expired.
no setter
key String
The query key
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storageDuration Duration?
The length of time before the query expires.
final

Methods

copyWith({String? key, dynamic data, DateTime? createdAt, Duration? storageDuration}) StoredQuery
Create a new StoredQuery from from the current instance.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override