InfiniteQueryInitial<T, Arg> class
final
The initial state of the query, before the queryFn has been called.
- Inheritance
-
- Object
- InfiniteQueryStatus<
T, Arg> - InfiniteQueryInitial
Constructors
-
InfiniteQueryInitial({required DateTime timeCreated, InfiniteQueryData<
T, Arg> ? data}) -
The initial state of the query, before the
queryFnhas been called.const
Properties
-
data
→ InfiniteQueryData<
T, Arg> ? -
The data stored in the query;
final
- error → dynamic
-
Returns the current error if the query is in an error state.
no setterinherited
- firstPage → T?
-
The first page of data returned from the queryFn
no setterinherited
- hashCode → int
-
The hash code for this object.
no setteroverride
- isError → bool
-
True if the query has errored.
no setterinherited
- isInitial → bool
-
True if the query is in the initial state.
no setterinherited
- isLoading → bool
-
True if the query is currently fetching data.
no setterinherited
- isSuccess → bool
-
True if the query has successfully fetched data.
no setterinherited
- lastPage → T?
-
The last page of data returned from the queryFn
no setterinherited
- length → int
-
The number of pages that have been fetched
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeCreated → DateTime
-
Timestamp of the query.
finalinherited
Methods
-
copyWithData(
InfiniteQueryData< T, Arg> ? data, [DateTime? timeCreated]) → InfiniteQueryInitial<T, Arg> -
Copy the current state with new data
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override